@@ -31,6 +31,8 @@ NOMADSRealTimeList <- function(url.type, abbrev = NULL) {
     "ngac_a2d",
     "ngac_a3d",
     "ngac_aod",
+    "cfs_flx",
+    "cfs_pgb",
     "aqm_daily",
     "aqm_ozone_1hr",
     "hiresak",
@@ -90,6 +92,8 @@ NOMADSRealTimeList <- function(url.type, abbrev = NULL) {
     "NOAA Environmental ing System Global Forecast System Aerosol Optical Depth",
     "Air Quality Daily Maximum",
     "Air Quality Hourly Surface Ozone",
+    "Climate Forecast System Flux Products",
+    "Climate Forecast System 3D Pressure Products",
     "High Res Window Alaska",
     "High Res Window - East Continental United States",
     "High Res Window - Guam",
